Loading Objects — SQLAlchemy 1.3 Documentation

Release: 1.3.7 | Release Date: August 14, 2019

# SQLAlchemy 1.3 Documentation

# Loading Objects

Notes and features regarding the general loading of mapped objects.

For an in-depth introduction to querying with the SQLAlchemy ORM, please see the Object Relational Tutorial.

- Loading Columns
  - Deferred Column Loading
  - Column Bundles
- Relationship Loading Techniques
  - Configuring Loader Strategies at Mapping Time
  - Relationship Loading with Loader Options
  - Lazy Loading
  - Joined Eager Loading
  - Subquery Eager Loading
  - Select IN loading
  - What Kind of Loading to Use ?
  - Polymorphic Eager Loading
  - Wildcard Loading Strategies
  - Routing Explicit Joins/Statements into Eagerly Loaded Collections
  - Creating Custom Load Rules
  - Relationship Loader API
- Loading Inheritance Hierarchies
  - Using with_polymorphic
  - Polymorphic Selectin Loading
  - Referring to specific subtypes on relationships
  - Loading objects with joined table inheritance
  - Loading objects with single table inheritance
  - Inheritance Loading API
- Constructors and Object Initialization
- Query API
  - The Query Object
  - ORM-Specific Query Constructs